import asyncio
from tortoise import Tortoise

from .store import InlineBovineStore


async def create_tables():
    async with InlineBovineStore():
        await Tortoise.generate_schemas()


def main():
    asyncio.run(create_tables())


if __name__ == "__main__":
    main()



import asyncio
from tortoise import Tortoise

from .store import InlineBovineStore


async def cleanup():
    async with InlineBovineStore():
        client = Tortoise.get_connection("default")

        sql_query = """
        delete from storedjsonobject
           where object_type='REMOTE'
             and updated < (current_date - interval '3 day')
        """

        await client.execute_query(sql_query)


def main():
    asyncio.run(cleanup())


if __name__ == "__main__":
    main()



import os
from tortoise import Tortoise

from bovine_store import BovineAdminStore


class InlineBovineStore(BovineAdminStore):
    def __init__(self, domain: str = None):
        self.db_url = os.environ.get("BOVINE_DB_URL", "sqlite://bovine.sqlite3")

        super().__init__(domain=domain)

    async def __aenter__(self):
        await Tortoise.init(
            db_url=self.db_url, modules={"models": ["bovine_store.models"]}
        )

        return self

    async def __aexit__(self, exc_type, exc, tb):
        await Tortoise.close_connections()



import asyncio

from argparse import ArgumentParser

from .store import InlineBovineStore


async def register_user(handle_name, domain=None):
    async with InlineBovineStore(domain=domain) as store:
        bovine_name = await store.register(handle_name)
        print(f"Bovine name: {bovine_name}")


def main():
    parser = ArgumentParser()
    parser.add_argument(
        "handle_name",
        help="Register a new user, argument is the FediVerse handle name",
    )
    parser.add_argument(
        "--domain",
        help="domain the actor should be on, otherwise taken from bovine_config.toml",
        default=None,
    )

    args = parser.parse_args()

    asyncio.run(register_user(args.handle_name, args.domain))


if __name__ == "__main__":
    main()



import asyncio
import json

from argparse import ArgumentParser

from bovine.crypto import generate_ed25519_private_key, private_key_to_did_key
from bovine.types import Visibility

from .store import InlineBovineStore


async def manage_user(args):
    async with InlineBovineStore() as store:
        if not (args.new_did_key or args.did_key or args.properties):
            actor = await store.actor_for_name(args.bovine_name)

            print(
                json.dumps(
                    actor.actor_object.build(visibility=Visibility.OWNER), indent=2
                )
            )

            await actor.session.close()

        if args.new_did_key:
            secret = generate_ed25519_private_key()
            print(f"Your new secret: {secret}")
            didkey = private_key_to_did_key(secret)
            await store.add_did_key_to_actor(args.bovine_name, "key-from-tool", didkey)

        if args.did_key:
            name, didkey = args.did_key
            await store.add_did_key_to_actor(args.bovine_name, name, didkey)

        if args.properties:
            property_file = args.properties
            with open(property_file) as fp:
                properties = json.load(fp)
            await store.set_properties_for_actor(args.bovine_name, properties)


def main():
    parser = ArgumentParser()
    parser.add_argument(
        "bovine_name",
        help="Bovine name of the user to manage",
    )
    parser.add_argument(
        "--new_did_key",
        help="Generates a new did key for the Moo Client Flow",
        action="store_true",
    )
    parser.add_argument(
        "--did_key",
        help="Add a new did key for the Moo Client Flow",
        metavar=("key_name", "did_key"),
        nargs=2,
    )
    parser.add_argument(
        "--properties",
        help="sets the properties of the actor to the new file",
        metavar="properties_file",
    )

    args = parser.parse_args()

    asyncio.run(manage_user(args))


if __name__ == "__main__":
    main()



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bovine_tool']

package_data = \
{'': ['*']}

install_requires = \
['bovine-store>=0.2.1,<0.3.0']

setup_kwargs = {
    'name': 'bovine-tool',
    'version': '0.2.2',
    'description': 'Basic tools to administrate a bovine herd',
    'long_description': '# bovine_tool\n\nbovine_tool provides a CLI interface to manage bovine.\n\n## Configuration\n\nThe default database connection is "sqlite://bovine.sqlite3". This can be overwridden with the environment variable "BOVINE_DB_URL".\n\n## Quick start\n\nTo register a new user with a FediVerse handle use\n\n```bash\npython -m bovine_tool.register fediverse_handle [--domain DOMAIN]\n```\n\nthe domain must be specified.\n\n## Managing users\n\n```bash\npython -m bovine_tool.manage bovine_name\n```\n\ndisplays the user.\n\nTo add a did key for [the Moo Client Registration Flow](https://blog.mymath.rocks/2023-03-25/BIN2_Moo_Client_Registration_Flow) with a BovineClient use\n\n```bash\npython -m bovine_tool.manage bovine_name --did_key key_name did_key\n```\n\nFurthermore, using `--properties` the properties can be over written.\n\n## Todo\n\n- [ ] Add ability to delete stale data, e.g. remote data older than X days\n- [ ] Add ability to import/export all data associated with an actor\n',
    'author': 'Helge',
    'author_email': 'helge.krueger@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://codeberg.org/bovine/bovine',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)
